@@ -4,8 +4,7 @@ from pydantic import BaseModel, HttpUrl
 
 
 class ListRequest(BaseModel):
-    is_leaf : Optional[bool]
-    type : Optional[Literal["openid_relying_party", "openid_provider", "oauth_resource", "federation_entity"]]
+    entity_type : Optional[Literal["openid_relying_party", "openid_provider", "oauth_resource", "federation_entity"]]
 
     def example():  # pragma: no cover
         return ListRequest(
