@@ -6,5 +6,7 @@ from pydantic import BaseModel, HttpUrl, EmailStr
 class FAMetadata(BaseModel):
     contacts: List[EmailStr]
     federation_fetch_endpoint: HttpUrl
+    federation_resolve_endpoint: HttpUrl
+    federation_list_endpoint: HttpUrl
     homepage_uri: HttpUrl
-    name: str
+    organization_name: str
