@@ -1,5 +1,3 @@
-
-
 from django.test import Client, TestCase
 from django.urls import reverse
 from spid_cie_oidc.entity.models import FetchedEntityStatement, TrustChain
@@ -26,9 +24,8 @@ class RpLandingTest(TestCase):
 
         self.trust_chain = TrustChain.objects.create(
             sub=op_conf["sub"],
-            type="openid_provider",
             exp=EXP,
-            metadata=op_conf["metadata"]["openid_provider"],
+            metadata=op_conf["metadata"],
             status="valid",
             trust_anchor=self.ta_fes,
             is_active=True,
