@@ -177,7 +177,10 @@ class SpidCieOidcRpBeginView(SpidCieOidcRp, View):
         # add the signed request object
         authz_data_obj = deepcopy(authz_data)
         authz_data_obj["iss"] = client_conf["client_id"]
-        authz_data_obj["sub"] = client_conf["client_id"]
+        
+        # sub claim MUST not be used to prevent that this jwt
+        # could be reused as a private_key_jwt
+        # authz_data_obj["sub"] = client_conf["client_id"]
 
         request_obj = create_jws(authz_data_obj, entity_conf.jwks_core[0])
         authz_data["request"] = request_obj
